@@ -31,7 +31,7 @@ use uv_resolver::{
     AnnotationStyle, DependencyMode, DisplayResolutionGraph, InMemoryIndex, Manifest,
     OptionsBuilder, PreReleaseMode, ResolutionMode, Resolver,
 };
-use uv_traits::{InFlight, NoBuild, SetupPyStrategy};
+use uv_traits::{ConfigSettings, InFlight, NoBuild, SetupPyStrategy};
 use uv_warnings::warn_user;
 
 use crate::commands::reporters::{DownloadReporter, ResolverReporter};
@@ -58,6 +58,7 @@ pub(crate) async fn pip_compile(
     include_find_links: bool,
     index_locations: IndexLocations,
     setup_py: SetupPyStrategy,
+    config_settings: ConfigSettings,
     connectivity: Connectivity,
     no_build: &NoBuild,
     python_version: Option<PythonVersion>,
@@ -219,6 +220,7 @@ pub(crate) async fn pip_compile(
         &in_flight,
         interpreter.sys_executable().to_path_buf(),
         setup_py,
+        &config_settings,
         no_build,
         &NoBinary::None,
     )
@@ -350,14 +352,7 @@ pub(crate) async fn pip_compile(
         writeln!(
             writer,
             "{}",
-            format!(
-                "#    uv {}",
-                env::args_os()
-                    .skip(1)
-                    .map(|arg| arg.normalized_display().to_string())
-                    .join(" ")
-            )
-            .green()
+            format!("#    {}", cmd(include_index_url)).green()
         )?;
     }
 
@@ -396,13 +391,43 @@ pub(crate) async fn pip_compile(
             &resolution,
             generate_hashes,
             include_annotations,
-            annotation_style
+            annotation_style,
         )
     )?;
 
     Ok(ExitStatus::Success)
 }
 
+/// Format the `uv` command used to generate the output file.
+fn cmd(include_index_url: bool) -> String {
+    let args = env::args_os()
+        .skip(1)
+        .map(|arg| arg.normalized_display().to_string())
+        .scan(None, move |skip_next, arg| {
+            if let Some(true) = skip_next {
+                // Reset state; skip this iteration.
+                *skip_next = None;
+                Some(None)
+            } else if !include_index_url
+                && (arg.starts_with("--extra-index-url=") || arg.starts_with("--index-url="))
+            {
+                // Reset state; skip this iteration.
+                *skip_next = None;
+                Some(None)
+            } else if !include_index_url && (arg == "--extra-index-url" || arg == "--index-url") {
+                // Mark the next item as (to be) skipped.
+                *skip_next = Some(true);
+                Some(None)
+            } else {
+                // Return the argument.
+                Some(Some(arg))
+            }
+        })
+        .flatten()
+        .join(" ");
+    format!("uv {args}")
+}
+
 /// Whether to allow package upgrades.
 #[derive(Debug)]
 pub(crate) enum Upgrade {
